Type: Package
Package: SomaDataIO
Title: Input/Output 'SomaScan' Data
Version: 6.6.1
Authors@R: c(
    person(given = "Stu",
           family = "Field",
           role = "aut",
           email = "stu.g.field@gmail.com",
           comment = c(ORCID = "0000-0002-1024-5859")),
    person(given = "Caleb",
           family = "Scheidel",
           role = "cre",
           email = "calebjscheidel@gmail.com"),    
    person(given = "SomaLogic Operating Co., Inc.", role = c("cph", "fnd"))
    )
Description: Load and export 'SomaScan' data via the
    'SomaLogic Operating Co., Inc.' structured text file
    called an ADAT ('*.adat'). For file format see
    <https://github.com/SomaLogic/SomaLogic-Data/blob/main/README.md>.
    The package also exports auxiliary functions for
    manipulating, wrangling, and extracting relevant
    information from an ADAT object once in memory.
License: MIT + file LICENSE
URL: https://somalogic.github.io/SomaDataIO/, https://somalogic.com
BugReports: https://github.com/SomaLogic/SomaDataIO/issues
Depends: R (>= 4.1.0)
Imports: cli, dplyr (>= 1.0.6), ggplot2, lifecycle (>= 1.0.0), magrittr
        (>= 2.0.1), methods, readxl (>= 1.3.1), tibble (>= 3.1.2),
        tidyr (>= 1.1.3)
Suggests: Biobase, knitr, purrr, recipes, rlang, rmarkdown, spelling,
        testthat (>= 3.0.0), usethis (>= 2.0.1), withr
VignetteBuilder: knitr
Copyright: SomaLogic Operating Co., Inc. 2026
Encoding: UTF-8
Language: en-US
LazyData: true
LazyDataCompression: xz
LazyLoad: true
Config/testthat/edition: 3
Config/Needs/website: tidyverse/tidytemplate
RoxygenNote: 7.3.3
NeedsCompilation: no
Packaged: 2026-05-15 18:20:39 UTC; cscheidel
Author: Stu Field [aut] (ORCID: <https://orcid.org/0000-0002-1024-5859>),
  Caleb Scheidel [cre],
  SomaLogic Operating Co., Inc. [cph, fnd]
Maintainer: Caleb Scheidel <calebjscheidel@gmail.com>
Repository: CRAN
Date/Publication: 2026-05-15 21:50:03 UTC
Built: R 4.5.2; ; 2026-05-15 22:52:05 UTC; unix
