# Generated by roxygen2: do not edit by hand

S3method("$",soma_adat)
S3method("$<-",soma_adat)
S3method("==",soma_adat)
S3method("[",soma_adat)
S3method("[<-",soma_adat)
S3method("[[",soma_adat)
S3method("[[<-",soma_adat)
S3method("row.names<-",soma_adat)
S3method(Math,soma.adat)
S3method(Math,soma_adat)
S3method(Ops,soma_adat)
S3method(Summary,soma_adat)
S3method(anti_join,soma_adat)
S3method(arrange,soma_adat)
S3method(count,soma_adat)
S3method(filter,soma_adat)
S3method(full_join,soma_adat)
S3method(getAdatVersion,default)
S3method(getAdatVersion,list)
S3method(getAdatVersion,soma_adat)
S3method(getAnalytes,character)
S3method(getAnalytes,data.frame)
S3method(getAnalytes,default)
S3method(getAnalytes,list)
S3method(getAnalytes,matrix)
S3method(getAnalytes,recipe)
S3method(getAnalytes,soma_adat)
S3method(getMeta,character)
S3method(getMeta,data.frame)
S3method(getMeta,default)
S3method(getMeta,list)
S3method(getMeta,matrix)
S3method(getMeta,soma_adat)
S3method(group_by,soma_adat)
S3method(inner_join,soma_adat)
S3method(is_seqFormat,character)
S3method(is_seqFormat,data.frame)
S3method(is_seqFormat,default)
S3method(is_seqFormat,soma_adat)
S3method(left_join,soma_adat)
S3method(median,soma_adat)
S3method(merge,soma_adat)
S3method(mutate,soma_adat)
S3method(plot,Map)
S3method(plot,outlier_map)
S3method(print,adat_summary)
S3method(print,outlier_map)
S3method(print,soma_adat)
S3method(print,target_map)
S3method(rename,soma_adat)
S3method(right_join,soma_adat)
S3method(sample_frac,soma_adat)
S3method(sample_n,soma_adat)
S3method(select,soma_adat)
S3method(semi_join,soma_adat)
S3method(separate,soma_adat)
S3method(slice,soma_adat)
S3method(slice_sample,soma_adat)
S3method(summary,soma_adat)
S3method(transform,soma_adat)
S3method(ungroup,soma_adat)
S3method(unite,soma_adat)
export("%>%")
export(adat2eSet)
export(addAttributes)
export(addClass)
export(add_rowid)
export(anti_join)
export(antilog)
export(apt2seqid)
export(arrange)
export(calcOutlierMap)
export(calc_eLOD)
export(checkSomaScanVersion)
export(cleanNames)
export(col2rn)
export(collapseAdats)
export(count)
export(diffAdats)
export(filter)
export(full_join)
export(getAdatVersion)
export(getAnalyteInfo)
export(getAnalytes)
export(getFeatureData)
export(getFeatures)
export(getMeta)
export(getOutlierIds)
export(getSeqId)
export(getSeqIdMatches)
export(getSignalSpace)
export(getSomaScanLiftCCC)
export(getSomaScanVersion)
export(getSomamerData)
export(getSomamers)
export(getTargetNames)
export(group_by)
export(has_rn)
export(inner_join)
export(is.AptName)
export(is.SeqId)
export(is.apt)
export(is.intact.attributes)
export(is.soma_adat)
export(is_intact_attr)
export(is_lifted)
export(is_seqFormat)
export(left_join)
export(lift_adat)
export(loadAdatsAsList)
export(locateSeqId)
export(matchSeqIds)
export(medianNormalize)
export(meltExpressionSet)
export(merge_clin)
export(mutate)
export(parseHeader)
export(pivotExpressionSet)
export(preProcessAdat)
export(read.adat)
export(read_adat)
export(read_annotations)
export(regexSeqId)
export(rename)
export(reverseMedianNormalize)
export(right_join)
export(rm_rn)
export(rn2col)
export(sample_frac)
export(sample_n)
export(semi_join)
export(separate)
export(seqid2apt)
export(set_rn)
export(slice)
export(slice_sample)
export(ungroup)
export(unite)
export(updateColMeta)
export(write_adat)
importFrom(dplyr,across)
importFrom(dplyr,all_of)
importFrom(dplyr,anti_join)
importFrom(dplyr,any_of)
importFrom(dplyr,arrange)
importFrom(dplyr,count)
importFrom(dplyr,filter)
importFrom(dplyr,full_join)
importFrom(dplyr,group_by)
importFrom(dplyr,inner_join)
importFrom(dplyr,left_join)
importFrom(dplyr,mutate)
importFrom(dplyr,rename)
importFrom(dplyr,right_join)
importFrom(dplyr,row_number)
importFrom(dplyr,sample_frac)
importFrom(dplyr,sample_n)
importFrom(dplyr,select)
importFrom(dplyr,semi_join)
importFrom(dplyr,slice)
importFrom(dplyr,slice_sample)
importFrom(dplyr,starts_with)
importFrom(dplyr,summarise)
importFrom(dplyr,ungroup)
importFrom(ggplot2,aes)
importFrom(ggplot2,element_blank)
importFrom(ggplot2,element_rect)
importFrom(ggplot2,element_text)
importFrom(ggplot2,facet_wrap)
importFrom(ggplot2,geom_boxplot)
importFrom(ggplot2,geom_hline)
importFrom(ggplot2,geom_point)
importFrom(ggplot2,geom_raster)
importFrom(ggplot2,geom_vline)
importFrom(ggplot2,ggplot)
importFrom(ggplot2,ggsave)
importFrom(ggplot2,guide_axis)
importFrom(ggplot2,guide_colorbar)
importFrom(ggplot2,guide_legend)
importFrom(ggplot2,guides)
importFrom(ggplot2,labs)
importFrom(ggplot2,scale_color_manual)
importFrom(ggplot2,scale_fill_gradientn)
importFrom(ggplot2,scale_fill_manual)
importFrom(ggplot2,scale_x_continuous)
importFrom(ggplot2,scale_x_discrete)
importFrom(ggplot2,scale_y_reverse)
importFrom(ggplot2,sec_axis)
importFrom(ggplot2,theme)
importFrom(ggplot2,theme_bw)
importFrom(ggplot2,unit)
importFrom(ggplot2,ylim)
importFrom(lifecycle,deprecate_soft)
importFrom(lifecycle,deprecate_stop)
importFrom(lifecycle,deprecate_warn)
importFrom(lifecycle,deprecated)
importFrom(lifecycle,is_present)
importFrom(magrittr,"%>%")
importFrom(methods,new)
importFrom(methods,setGeneric)
importFrom(methods,validObject)
importFrom(readxl,read_xlsx)
importFrom(stats,IQR)
importFrom(stats,mad)
importFrom(stats,median)
importFrom(stats,sd)
importFrom(stats,setNames)
importFrom(tibble,as_tibble)
importFrom(tibble,deframe)
importFrom(tibble,enframe)
importFrom(tibble,is_tibble)
importFrom(tibble,tibble)
importFrom(tidyr,gather)
importFrom(tidyr,pivot_longer)
importFrom(tidyr,separate)
importFrom(tidyr,unite)
importFrom(utils,capture.output)
importFrom(utils,head)
importFrom(utils,read.csv)
importFrom(utils,read.delim)
importFrom(utils,tail)
importFrom(utils,write.table)
