
#' @importFrom dplyr count
#' @export
dplyr::count

#' @importFrom dplyr rename
#' @export
dplyr::rename

#' @importFrom dplyr slice_sample
#' @export
dplyr::slice_sample

#' @importFrom dplyr slice
#' @export
dplyr::slice

#' @importFrom dplyr sample_frac
#' @export
dplyr::sample_frac

#' @importFrom dplyr sample_n
#' @export
dplyr::sample_n

#' @importFrom dplyr filter
#' @export
dplyr::filter

#' @importFrom dplyr mutate
#' @export
dplyr::mutate

#' @importFrom dplyr arrange
#' @export
dplyr::arrange

#' @importFrom dplyr group_by
#' @export
dplyr::group_by

#' @importFrom dplyr ungroup
#' @export
dplyr::ungroup

#' @importFrom dplyr left_join
#' @export
dplyr::left_join

#' @importFrom dplyr anti_join
#' @export
dplyr::anti_join

#' @importFrom dplyr full_join
#' @export
dplyr::full_join

#' @importFrom dplyr inner_join
#' @export
dplyr::inner_join

#' @importFrom dplyr semi_join
#' @export
dplyr::semi_join

#' @importFrom dplyr right_join
#' @export
dplyr::right_join
