#' Common Parameters in \pkg{SomaDataIO}
#'
#' The parameters below are commonly used throughout
#'   the \pkg{SomaDataIO} package.
#'
#' @name params
#'
#' @param adat A `soma_adat` object (with intact attributes),
#'   typically created using [read_adat()].
#'
#' @param x A `soma_adat` object (with intact attributes),
#'   typically created using [read_adat()].
#'
#' @param matrix Character. A string of (usually) either 
#'   `"serum"` or `"plasma"`.
#'
#' @return A `soma_adat` class object.
NULL
