# `merge.soma_adat()` triggers the expected lifecycle error messages

    Using `merge()` on a `soma_adat` was deprecated in SomaDataIO 6.0.0 and is now defunct.
    i Please use any of the `dplyr::*_join()` alternatives instead.
    i Perhaps [90m`dplyr::left_join(x = data, y = merge_data, by = "SampleId")`[39m?

