# `getTargetNames()` S3 print method for `target_map` snapshots

    == AptName-Target Lookup Map ===================================================
    # A tibble: 5,284 x 2
       AptName       Target                                                
       <chr>         <chr>                                                 
     1 seq.10000.28  Beta-crystallin B2                                    
     2 seq.10001.7   RAF proto-oncogene serine/threonine-protein kinase    
     3 seq.10003.15  Zinc finger protein 41                                
     4 seq.10006.25  ETS domain-containing protein Elk-1                   
     5 seq.10008.43  Guanylyl cyclase-activating protein 1                 
     6 seq.10011.65  Inositol polyphosphate 5-phosphatase OCRL-1           
     7 seq.10012.5   SAM pointed domain-containing Ets transcription factor
     8 seq.10013.34  Fc_MOUSE                                              
     9 seq.10014.31  Zinc finger protein SNAI2                             
    10 seq.10015.119 Voltage-gated potassium channel subunit beta-2        
    # i 5,274 more rows
    ================================================================================

